*==========================================================
* setting more off, processors, working directory
*==========================================================
clear
set more off
macro drop _all
set scheme s1color // plotplain s2mono s1color s1mono lean1

cap cd "/storage/work/s/sxz217/landrental/"
global data = "$pwd" + "data"
global results = "$pwd" + "results"

*==========================================================
* imputation (add 20) and modeling
*==========================================================
*===============================
*	load data
*===============================
use "$data/panelwithsvy",clear
drop if ssu == .
// drop province
drop if panelwt == .
nmissing
mdesc
sum

*===============================
*	mi set data
*===============================
mi set mlong
mi misstable sum
mi misstable patterns

*===============================
*	mi reshape wide for imputation
*===============================
mi reshape wide y hhage hhedu hhgender hhmarried ///
	familysize familyinc wageinc selfemploy agincome ///
    agmachine agsubsidy medicaredum pensiondum ///
    province region psu ssu panelwt, ///
    i(fid)j(year)
des,s

*===============================
*	mi register imputed (13)
*===============================
mi register imputed ///
	hhage* ///
	hhedu* ///
	hhgender* ///
	hhmarried* ///
	familyinc* ///
	wageinc* ///
	agincome* ///
	landarea ///
	agmachine* ///
	agsubsidy* ///
	mktdistance ///
	pensiondum* ///
	medicaredum*

*===============================
*	mi impute chained: PMM
*===============================
mi impute chained (logit) hhgender* pensiondum* medicaredum* ///
	agsubsidy* hhmarried* ///
	(pmm,knn(5)) hhage* familyinc* wageinc* agincome* ///
	landarea agmachine* mktdistance hhedu* = ///
	familysize* i.selfemploy*, ///
	add(20) rseed(19941122) dots noisily force

*===============================
*	mi reshape long for modeling
*===============================
mi reshape long y hhage hhedu hhgender hhmarried ///
    familysize familyinc wageinc selfemploy agincome ///
    agmachine agsubsidy medicaredum pensiondum ///
    province region psu ssu panelwt, ///
    i(fid)j(year)

*===============================
*	rescale variables using: mi passive
*===============================
// *	divide by 1000
// mi passive: gen familyinc_1000 = familyinc/1000
// mi passive: gen wageinc_1000 = wageinc/1000
// mi passive: gen agincome_1000 = agincome/1000
// mi passive: gen agmachine_1000 = agmachine/1000

* rescale
mi passive: gen landareaha = landarea*(1/15)
mi passive: gen mktdishour = mktdistance/60

* log transformation
mi passive: gen familyinc_log = log(familyinc)
mi passive: gen wageinc_log = log(wageinc)
mi passive: gen agincome_log = log(agincome)
mi passive: gen agmachine_log = log(agmachine)
replace familyinc_log = 0 if familyinc == 0
replace wageinc_log = 0 if wageinc == 0
replace agincome_log = 0 if agincome == 0
replace agmachine_log = 0 if agmachine == 0

*	generate age square
mi passive: gen hhage2 = hhage ^ 2

*	generate dummy for region and place
mi xeq: tab region, gen(region)
mi xeq: tab year, gen(year)

*===============================
*	order variables
*===============================
order fid year y ///
hhage hhage2 hhgender hhmarried hhedu ///
familysize selfemploy ///
familyinc* wageinc* agincome* ///
land* agma* ///
agsubsidy pensiondum medicaredum ///
mktdistance mktdishour region* year* province ///
panelwt psu ssu

*===============================
*	save imputed data
*===============================
save "$data/imputed20withsvy.dta", replace

// *==========================================================
// * clear memory and exit
// *==========================================================
// exit, clear STATA


*=========================== END ===========================

