*==========================================================
* setting more off, processors, working directory
*==========================================================
clear
set more off
macro drop _all
set scheme s1color // plotplain s2mono s1color s1mono lean1

cap cd "/storage/work/s/sxz217/landrental/"
global data = "$pwd" + "data"
global results = "$pwd" + "results"

*==========================================================
* logging
*==========================================================
capture log close _all
log using "$results/S4.2_OLSModel_Diag.log", replace

*==========================================================
* get R2 from model with imputation
*==========================================================
use "$data/imputed20withsvy.dta", clear
mi set
mi xtset fid year

mi query
local M = r(M)
scalar r2_p = 0
mi xeq 1/`M': ///
	logit y ///
	familysize hhage hhage2 hhedu hhgender hhmarried ///
	selfemploy wageinc_log agincome_log landareaha agmachine_log ///
	agsubsidy pensiondum medicaredum mktdishour ///
	region2 region3 region4 ///
	year2 year3; scalar r2_p = r2_p + e(r2_p)
scalar r2_p = r2_p/`M'
dis as txt "Pseudo R2 over imputed data = " as res r2_p

*==========================================================
* get Log Likelihood (LL) from model with imputation
*==========================================================
mi query
local M = r(M)
scalar ll_ols = 0
mi xeq 1/`M': ///
	logit y ///
	familysize hhage hhage2 hhedu hhgender hhmarried ///
	selfemploy wageinc_log agincome_log landareaha agmachine_log ///
	agsubsidy pensiondum medicaredum mktdishour ///
	region2 region3 region4 ///
	year2 year3; scalar ll_ols = ll_ols + e(ll)
scalar ll_ols = ll_ols/`M'
dis as txt "Log Likelihood (LL) over imputed data = " as res ll_ols

*==========================================================
* end logging
*==========================================================
log close _all

// *==========================================================
// * clear memory and exit
// *==========================================================
// exit, clear STATA


*=========================== END ===========================

