*==========================================================
* setting more off, processors, working directory
*==========================================================
clear
set more off
macro drop _all
set scheme s1color // plotplain s2mono s1color s1mono lean1

cap cd "/storage/work/s/sxz217/landrental/"
global data = "$pwd" + "data"
global results = "$pwd" + "results"

*==========================================================
* logging
*==========================================================
capture log close _all
log using "$results/S5.2_PanelModel_Diag.log", replace

*==========================================================
* get R2 from fixed model with imputation
*==========================================================
use "$data/imputed20withsvy.dta", clear
mi set
mi xtset fid year

mi query
local M = r(M)
scalar r2_p = 0
mi xeq 1/`M': ///
	xtlogit y ///
	familysize hhage hhage2 hhedu hhgender hhmarried ///
	selfemploy wageinc_log agincome_log landareaha agmachine_log ///
	agsubsidy pensiondum medicaredum mktdishour ///
	region2 region3 region4 ///
	year2 year3, fe; scalar r2_p = r2_p + e(r2_p)
scalar r2_p = r2_p/`M'
dis as txt "Pseudo R2 over imputed data (fixed-effects) = " as res r2_p

*==========================================================
* get Log Likelihood (LL) from model with imputation
*==========================================================
**===============================================
** fixed effect model
**===============================================
use "$data/imputed20withsvy.dta", clear
mi set
mi xtset fid year

mi query
local M = r(M)
scalar ll_fe = 0
mi xeq 1/`M': ///
	xtlogit y ///
	familysize hhage hhage2 hhedu hhgender hhmarried ///
	selfemploy wageinc_log agincome_log landareaha agmachine_log ///
	agsubsidy pensiondum medicaredum mktdishour ///
	region2 region3 region4 ///
	year2 year3, fe; scalar ll_fe = ll_fe + e(ll)
scalar ll_fe = ll_fe/`M'
dis as txt "Log Likelihood (LL) over imputed data (fixed-effects) = " as res ll_fe

**===============================================
** random effect model
**===============================================
use "$data/imputed20withsvy.dta", clear
mi set
mi xtset fid year

mi query
local M = r(M)
scalar ll_re = 0
mi xeq 1/`M': ///
	xtlogit y ///
	familysize hhage hhage2 hhedu hhgender hhmarried ///
	selfemploy wageinc_log agincome_log landareaha agmachine_log ///
	agsubsidy pensiondum medicaredum mktdishour ///
	region2 region3 region4 ///
	year2 year3, fe; scalar ll_re = ll_re + e(ll)
scalar ll_re = ll_re/`M'
dis as txt "Log Likelihood (LL) over imputed data (random-effects) = " as res ll_re

*==========================================================
* display all results
*==========================================================
dis as txt "Pseudo R2 over imputed data (fixed-effects) = " as res r2_p
dis as txt "Log Likelihood (LL) over imputed data (fixed-effects) = " as res ll_fe
dis as txt "Log Likelihood (LL) over imputed data (random-effects) = " as res ll_re

*==========================================================
* end logging
*==========================================================
log close _all

// *==========================================================
// * clear memory and exit
// *==========================================================
// exit, clear STATA


*=========================== END ===========================

